@@ -89,9 +89,9 @@ Refer to documentation.
 from django import VERSION
 from django.conf import settings
 if VERSION < (2, 0):
-    from django.conf.urls import url as re_path
+    from django.conf.urls import include, url as re_path
 else:
-    from django.urls import re_path
+    from django.urls import include, re_path
 if getattr(settings, 'POSTMAN_I18N_URLS', False):
     from django.utils.translation import pgettext_lazy
 else:
@@ -101,6 +101,7 @@ from .views import (InboxView, SentView, ArchivesView, TrashView,
         WriteView, ReplyView, MessageView, ConversationView,
         ArchiveView, DeleteView, UndeleteView, MarkReadView, MarkUnreadView,
         IndexView)
+from . import api_urls
 
 app_name = 'postman'
 urlpatterns = [
@@ -123,4 +124,6 @@ urlpatterns = [
     re_path(pgettext_lazy('postman_url', r'^mark-read/$'), MarkReadView.as_view(), name='mark-read'),
     re_path(pgettext_lazy('postman_url', r'^mark-unread/$'), MarkUnreadView.as_view(), name='mark-unread'),
     re_path(r'^$', IndexView.as_view()),
+
+    re_path(pgettext_lazy('postman_url', r'^api/'), include(api_urls)),
 ]
