@@ -83,7 +83,7 @@ class FolderMixin(NamespaceMixin, object):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        params = {}
+        params = {'query_dict': self.request.GET}
         option = kwargs.get('option')
         if option:
             params['option'] = option
